summaryrefslogtreecommitdiffstats
path: root/games/grdc/grdc.c
diff options
context:
space:
mode:
Diffstat (limited to 'games/grdc/grdc.c')
-rw-r--r--games/grdc/grdc.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/games/grdc/grdc.c b/games/grdc/grdc.c
index 823b1d3..55e579f 100644
--- a/games/grdc/grdc.c
+++ b/games/grdc/grdc.c
@@ -1,6 +1,6 @@
/*
* Grand digital clock for curses compatible terminals
* Usage: gdc [-s] [n] -- run for n seconds (default infinity)
* Flags: -s: scroll
*
* modified 10-18-89 for curses (jrl)
@@ -151,7 +151,7 @@ int n = 0;
clear();
refresh();
endwin();
- fprintf(stderr, "gdc terminated by signal %d\n", sigtermed);
+ fprintf(stderr, "grdc terminated by signal %d\n", sigtermed);
exit(1);
}
} while(--n);
@@ -1,6 +1,6 @@
/*
* Grand digital clock for curses compatible terminals
- * Usage: gdc [-s] [n] -- run for n seconds (default infinity)
+ * Usage: grdc [-s] [n] -- run for n seconds (default infinity)
* Flags: -s: scroll
*
OpenPOWER on IntegriCloud